==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/get_file.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


include "config/config_aroundme.inc.php";

if (isset($_REQUEST['sid'])) {
	session_start();
}

$path = $c_node['dir']['asset_path'] . $_REQUEST['file'];

if (is_file($path)) {
	$extension = substr($path, -3);
	
	global $c_node;
	
	$mime = "image/png";
	
	foreach($c_node['file']['mime'] as $key => $i):
		if ($extension == $i['suffix']) {
			$mime = $c_node['file']['mime'][$key]['mime'];
			break;
		}
	endforeach;
	
	header("Content-type: " . $mime);
	
    @readfile($path);
}
else {
	$path = $c_node['dir']['asset_path'] . $c_node['file']['image']['broken_image'];
	header("Content-type: image/png");
	@readfile($path);
}

?>

==> aroundme_0_6_4.zip: aroundme_0_6_4/aroundme/get_file.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


include "config/config_aroundme.inc.php";

if (isset($_REQUEST['sid'])) {
	session_start();
}

$path = $c_node['dir']['asset_path'] . $_REQUEST['file'];

if (is_file($path)) {
	$extension = substr($path, -3);
	
	global $c_node;
	
	$mime = "image/png";
	
	foreach($c_node['file']['mime'] as $key => $i):
		if ($extension == $i['suffix']) {
			$mime = $c_node['file']['mime'][$key]['mime'];
			break;
		}
	endforeach;
	
	header("Content-type: " . $mime);
	
    @readfile($path);
}
else {
	$path = $c_node['dir']['asset_path'] . $c_node['file']['image']['broken_image'];
	header("Content-type: image/png");
	@readfile($path);
}

?>
